#[non_exhaustive]pub enum Error {
IO(Error),
AlreadyInitialized,
InvalidConfiguration(String),
InvalidEnvironmentValue {
variable: String,
expected: &'static str,
},
ForeignGlobalSubscriber,
ForeignGlobalLogger,
InstallationIncomplete,
}Expand description
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
IO(Error)
I/O failure during subscriber setup (typically the journald socket).
AlreadyInitialized
This crate already installed the subscriber and idempotent was false.
InvalidConfiguration(String)
The requested options are not supported on the selected target.
InvalidEnvironmentValue
An environment variable contains an unsupported or malformed value.
Fields
ForeignGlobalSubscriber
Another crate installed the process-global tracing subscriber.
ForeignGlobalLogger
Another crate installed the process-global log facade.
The tracing subscriber and any OTLP provider are already committed when
this error is returned; only the log-to-tracing bridge is foreign.
InstallationIncomplete
A prior installation panicked after claiming the tracing subscriber.